Documentation
¶
Overview ¶
Package SocialMedia implements common functionality needed for social media web applications.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Moods map[string]MoodState
Map that holds the various mood states with keys to serve as aliases to their respective mood states.
var MoodsEmoji map[MoodState]string
Functions ¶
This section is empty.
Types ¶
type AuditableContent ¶
type AuditableContent struct {
TimeCreated time.Time `json:"timeCreated"`
TimeModified time.Time `json:"timeModified"`
TimeCreatedUnixTS int `json:"timeCreatedUnixTS"`
TimeModifiedUnixTS int `json:"timeModifiedUnixTS"`
CreatedBy string `json:"createdBy"`
ModifiedBy string `json:"modifiedBy"`
}
AuditableContent types are meant to be embeded into types we want to keep a check on for auditing purposes
type MoodState ¶
type MoodState int
type Post ¶
type Post struct {
AuditableContent // Embedded type
UUID string `json:"uuid"`
RawMoodValue int `json:"rawMoodValue"`
Username string `json:"username"`
ProfileImagePath string `json: "profileImagePath"`
Caption string `json:"caption"`
MessageBody string `json:"messageBody"`
URL string `json:"url"`
ImageURI string `json:"imageURI"`
ThumbnailURI string `json:"thumbnailURI"`
Keywords []string `json:"keywords"`
Likers []string `json:"likers"`
AuthorMood MoodState `json:"authorMood"`
AuthorMoodEmoji string `json:authorMoodEmoji"`
}
Post represents a Social Media Post type.
Click to show internal directories.
Click to hide internal directories.